/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import org.netbeans.api.project.Project;
import org.netbeans.api.project.ProjectManager;
import org.netbeans.spi.project.ui.support.DefaultProjectOperations;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser
 */
@ServiceProvider(service = FleetManager.class)
public class FleetManagerImpl implements FleetManager {

    @Override
    public Fleet load(FileObject fileObject) {
        Fleet fleet = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            fleet = (Fleet) ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        return fleet;
    }

    @Override
    public void save(Fleet fleet, FileObject fileObject) {
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(fleet);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        //
        // renaming project folder if farm name changed
        //
        try {
            FileObject projectDir = fileObject.getParent();

            if (!projectDir.getName().equals(fleet.getName())) {
                String actualNewName = FileUtil.findFreeFolderName(projectDir.getParent(), fleet.getName());
                Project project = ProjectManager.getDefault().findProject(projectDir);
                DefaultProjectOperations.performDefaultRenameOperation(project, actualNewName);
            }
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
    }
}
