/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet;

import java.awt.Image;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 *
 * @author Wytse Visser
 */
final class FleetNode extends FilterNode {

    private final FleetProject project;
    private final Node fleetFileNode;

    public FleetNode(Node fleetFileNode, Node projectFolderNode, FleetProject project) throws DataObjectNotFoundException {
        super(projectFolderNode,
                NodeFactorySupport.createCompositeChildren(project, "Projects/nl-cloudfarming-client-fleet/Nodes"),
                new ProxyLookup(new Lookup[]{Lookups.singleton(project),
                    fleetFileNode.getLookup()
                }));
        this.fleetFileNode = fleetFileNode;
        this.project = project;
    }

    @Override
    public String getDisplayName() {
        return project.getProjectDirectory().getName();
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(FleetProjectFactory.ICON);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }
}
