/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet;

import java.awt.Component;
import java.io.File;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.Enumeration;
import java.util.LinkedHashSet;
import java.util.NoSuchElementException;
import java.util.Set;
import javax.swing.JComponent;
import javax.swing.event.ChangeListener;
import org.netbeans.api.project.ProjectManager;
import org.netbeans.api.templates.TemplateRegistration;
import org.netbeans.spi.project.ui.support.ProjectChooser;
import org.netbeans.spi.project.ui.templates.support.Templates;
import org.openide.WizardDescriptor;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 *
 * @author Wytse Visser
 */
@TemplateRegistration(folder = "Project/Fleet", displayName = "#Fleet_displayName", description = "FleetDescription.html", iconBase = "nl/cloudfarming/client/fleet/fleet.png", content = "FleetProject.zip")
@Messages({"Fleet_displayName=Fleet"})
public class FleetWizardIterator implements WizardDescriptor.InstantiatingIterator {

    private int index;
    private WizardDescriptor.Panel[] panels;
    private WizardDescriptor wiz;
    public static final String PROP_PROJECT_NAME = "projectName";
    public static final String PROP_PROJECT_DIR = "projectDir";

    @Override
    public Set instantiate() throws IOException {
        Set<FileObject> resultSet = new LinkedHashSet<>();
        File projectDir = FileUtil.normalizeFile((File) wiz.getProperty(PROP_PROJECT_DIR));
        projectDir.mkdirs();

        FileObject template = Templates.getTemplate(wiz);
        FileObject dir = FileUtil.toFileObject(projectDir);
        //unZipFile(template.getInputStream(), dir);

        String name = (String) wiz.getProperty(PROP_PROJECT_NAME);

        // Create new Fleet and set name.
        Fleet fleet = new Fleet();
        fleet.setName(name);
        Lookup.getDefault().lookup(FleetManager.class).save(fleet, dir.createData(FleetProjectFactory.FLEET_FILE));

        dir.createFolder("Vehicles");
        dir.createFolder("Implements");

        // Always open top dir as a project:
        resultSet.add(dir);

//        Enumeration<? extends FileObject> e = dir.getFolders(false);
//        while (e.hasMoreElements()) {
//            FileObject subfolder = e.nextElement();
//            if (ProjectManager.getDefault().isProject(subfolder)) {
//                resultSet.add(subfolder);
//            }
//        }

        File parent = projectDir.getParentFile();
        if (parent != null
                && parent.exists()) {
            ProjectChooser.setProjectsFolder(parent);
        }

        return resultSet;
    }

    private String[] createSteps() {
        return new String[]{
                    NbBundle.getMessage(FleetWizardIterator.class, "LBL_CreateProjectStep"),};
    }

    private WizardDescriptor.Panel[] createPanels() {
        return new WizardDescriptor.Panel[]{
                    new FleetWizardNamePanel()
                };
    }

    @Override
    public void initialize(WizardDescriptor wiz) {
        this.wiz = wiz;
        index = 0;
        panels = createPanels();

        // Make sure list of steps is accurate.
        String[] steps = createSteps();
        for (int i = 0; i < panels.length; i++) {
            Component c = panels[i].getComponent();
            if (steps[i] == null) {
                // Default step name to component name of panel.
                // Mainly useful for getting the name of the target
                // chooser to appear in the list of steps.
                steps[i] = c.getName();
            }
            if (c instanceof JComponent) { // assume Swing components
                JComponent jc = (JComponent) c;
                // Step #.
                // TODO if using org.openide.dialogs >= 7.8, can use WizardDescriptor.PROP_*:
                jc.putClientProperty("WizardPanel_contentSelectedIndex", new Integer(i));
                // Step name (actually the whole list for reference).
                jc.putClientProperty("WizardPanel_contentData", steps);
            }
        }
    }

    @Override
    public void uninitialize(WizardDescriptor wd) {
        this.wiz.putProperty(PROP_PROJECT_DIR, null);
        this.wiz.putProperty(PROP_PROJECT_NAME, null);
        this.wiz = null;
        panels = null;
    }

    @Override
    public WizardDescriptor.Panel current() {
        return panels[index];
    }

    @Override
    public String name() {
        return MessageFormat.format("{0} of {1}",
                new Object[]{new Integer(index + 1), new Integer(panels.length)});
    }

    @Override
    public boolean hasNext() {
        return index < panels.length - 1;
    }

    @Override
    public boolean hasPrevious() {
        return index > 0;
    }

    @Override
    public void nextPanel() {
        if (!hasNext()) {
            throw new NoSuchElementException();
        }
        index++;
    }

    @Override
    public void previousPanel() {
        if (!hasPrevious()) {
            throw new NoSuchElementException();
        }
        index--;
    }

    @Override
    public void addChangeListener(ChangeListener cl) {
    }

    @Override
    public void removeChangeListener(ChangeListener cl) {
    }
}
