/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet;

import java.io.IOException;
import org.netbeans.api.project.Project;
import org.netbeans.api.project.ProjectManager;
import org.netbeans.spi.project.ProjectFactory;
import org.netbeans.spi.project.ProjectState;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser
 */
@ServiceProvider(service=ProjectFactory.class)
public class VehicleProjectFactory implements ProjectFactory {
    public static final String VEHICLES_DIR = "Vehicles";
    public static final String ICON = "nl/cloudfarming/client/fleet/vehicle.png";

    @Override
    public boolean isProject(FileObject projectDirectory) {
        return isVehicleProjectDirectory(projectDirectory) && hasFleetProjectParent(projectDirectory);
    }
    
    private boolean isVehicleProjectDirectory(FileObject projectDirectory) {
        return projectDirectory.getName().equalsIgnoreCase(VEHICLES_DIR);
    }
    
    private boolean hasFleetProjectParent(FileObject projectDirectory) {
        Project parentProject = null;
        try {
            parentProject = ProjectManager.getDefault().findProject(projectDirectory.getParent());
        } catch (Exception ex) {
            Exceptions.printStackTrace(ex);
        }
        return parentProject != null && parentProject instanceof FleetProject;
    }

    @Override
    public Project loadProject(FileObject dir, ProjectState state) throws IOException {
        return isProject(dir) ? new VehicleProject(dir, state) : null;
    }

    @Override
    public void saveProject(final Project project) throws IOException, ClassCastException {
        FileObject projectRoot = project.getProjectDirectory();
        if (projectRoot.getFileObject(VEHICLES_DIR) == null) {
            throw new IOException("Project dir " + projectRoot.getPath() +
                    " deleted," +
                    " cannot save project");
        }
    }
    
}
